#!/bin/sh

if [ "$#" -ne "4" ] ; then
  echo "Use: $0 target_cpu RPM_BUILD_ROOT RPM_BUILD_DIR CREATE"
  exit 1
fi

TARGET=$1
RPM_BUILD_ROOT=$2
RPM_BUILD_DIR=$3
# Create is for initial creatian, otherwise files are copied
CREATE=$4

case "$TARGET" in
  sparc|sparc64)
    ASM64="asm-sparc64"
    ASM="asm-sparc"
    DEF64="__arch64__"
    STUB="__SPARC_ASM_STUB__"
    NAME64="SPARC64"
    NAME32="SPARC32"
    ;;
  ppc|ppc64)
    ASM64="asm-ppc64"
    ASM="asm-ppc"
    DEF64="__powerpc64__"
    STUB="__PPC_ASM_STUB__"
    NAME64="PPC64"
    NAME32="PPC32"
    ;;
  x86_64)
    ASM64="asm-x86_64"
    ASM="asm-i386"
    DEF64="__x86_64__"
    STUB="__X86_64_ASM_STUB__"
    NAME64="X86-64"
    NAME32="x86"
    ;;
  s390|s390x)
    ASM64="asm-s390x"
    ASM="asm-s390"
    DEF64="__s390x__"
    STUB="__S390_ASM_STUB__"
    NAME64="S390x"
    NAME32="S390"
    ;;
esac

if [ "$CREATE" -eq "1" ] ; then
  mkdir $RPM_BUILD_DIR/kernel-headers/asm

  cd $RPM_BUILD_DIR/kernel-headers/asm
  for I in `( ls $RPM_BUILD_DIR/kernel-headers/$ASM; ls $RPM_BUILD_DIR/kernel-headers/$ASM64 ) | grep '\.h$' | sort -u`; do
	J=`echo $I | tr a-z.- A-Z__`
	cat > $I << EOF
#ifndef ${STUB}${J}__
#define ${STUB}${J}__
EOF
	if [ -f $RPM_BUILD_DIR/kernel-headers/$ASM/$I -a -f $RPM_BUILD_DIR/kernel-headers/$ASM64/$I ]; then
		cat >> $I <<EOF
#ifdef $DEF64
#include <$ASM64/$I>
#else
#include <$ASM/$I>
#endif
#endif
EOF
	elif [ -f $RPM_BUILD_DIR/kernel-headers/$ASM/$I ]; then
		cat >> $I <<EOF
#ifndef $DEF64
#include <$ASM/$I>
#else
#warning $I is not supported on $NAME64
#endif
#endif
EOF
	else
		cat >> $I <<EOF
#ifdef $DEF64
#include <$ASM64/$I>
#else
#warning $I is not supported on $NAME32
#endif
#endif
EOF
	fi
  done
else
  # Just copy the headers
  cp -a $RPM_BUILD_DIR/kernel-headers/$ASM $RPM_BUILD_ROOT/usr/include
  cp -a $RPM_BUILD_DIR/kernel-headers/$ASM64 $RPM_BUILD_ROOT/usr/include
  cp -a $RPM_BUILD_DIR/kernel-headers/asm $RPM_BUILD_ROOT/usr/include
fi

